2021-09-03 Version: 0.1.6
- Support query organization repository settings.
- Support trigger mirror sync openapi.

2021-08-25 Version: 0.1.5
- Support delete repo member with yunxiao uid.

2021-08-20 Version: 0.1.4
- Add ListRepositoryProtectdBranch API.
- Add GetFileLastCommit API.

2020-12-30 Version: 1.0.0
- AMP Version Change.

